const Main = imports.ui.main;
const Lang = imports.lang;
const PanelMenu = imports.ui.panelMenu;
const PopupMenu = imports.ui.popupMenu;
const St = imports.gi.St;
const Util = imports.misc.util;
const Gtk = imports.gi.Gtk;
const Gio = imports.gi.Gio;
const GLib = imports.gi.GLib;

const Gettext = imports.gettext.domain("gnome-shell-extensions-simple-font-manager");
const _ = Gettext.gettext;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = imports.misc.extensionUtils.getCurrentExtension();
const Convenience = Me.imports.convenience;

const SimpleFontManagerIndicator = new Lang.Class({
	Name: "SimpleFontManagerIndicator",
	Extends: PanelMenu.Button,

	_init: function() {
		this.parent(0.0, "SimpleFontManagerIndicator");
				
		this._icon = new St.Icon({ icon_name: 'simple-font-manager-indicator-symbolic', style_class: 'system-status-icon' });
		this.actor.add_actor(this._icon);
		
		this._fontGroup = null;
		this._fontGroup = new Array();
		this._fontGroupConnectId = null;
		this._fontGroupConnectId = new Array();
		
		this.updateMenu();
	},

	updateMenu: function() {
		this._removeMenu();
		
		let fontsPath = Gio.file_new_for_path(extension.settings.get_string("fonts-path"));
		let fontsPathChildren = fontsPath.enumerate_children("*", Gio.FileQueryInfoFlags.NONE, null);
		
		let fontPathGroup;
		let fontPathGroupSymLink;
		
		let itemFontGroup = [];
		
		let i = 0;
		let pos;

		while ( (fontPathGroup = fontsPathChildren.next_file(null)) != null) {
			if (fontPathGroup.get_file_type() == Gio.FileType.DIRECTORY) {
				fontPathGroupSymLink = Gio.file_new_for_path("/home/" + GLib.get_user_name() + "/.fonts/simple-font-manager-" + fontPathGroup.get_name());
				
				itemFontGroup[i] = new PopupMenu.PopupSwitchMenuItem(fontPathGroup.get_name(), fontPathGroupSymLink.query_exists(null));
				this._fontGroup[i] = itemFontGroup[i];
				this._fontGroup[i]._fontGroupName = fontPathGroup.get_name();
				
				this._fontGroupConnectId[i] = this._fontGroup[i].connect('toggled', Lang.bind(this, this._toggleSymlink));
				
				pos = 0;
				for (let a = 0; a <= i; a++) {
					if (itemFontGroup[i]._fontGroupName > itemFontGroup[a]._fontGroupName) {
						pos = pos + 1;
					}
				}
				
				this.menu.addMenuItem(itemFontGroup[i], pos);
				
				i++;
			}
		}
			
		fontsPathChildren.close(null);
		
		let itemSeparator = new PopupMenu.PopupSeparatorMenuItem();
		this.menu.addMenuItem(itemSeparator);
		
		this._itemSettings = new PopupMenu.PopupMenuItem(_("Settings"));
		this._itemSettings.connect("activate", Lang.bind(this, extension.launchSettings));
		this.menu.addMenuItem(this._itemSettings);
	},
	
	_toggleSymlink: function(fontGroup, bernd) {
		let symlinkFile = null;
		symlinkFile = Gio.file_new_for_path("/home/" + GLib.get_user_name() + "/.fonts/simple-font-manager-" + fontGroup._fontGroupName);
			
		if (symlinkFile.query_exists(null)) {
			try {
				symlinkFile.delete(null);
			} catch (err) {
			}
		} else {
			try {
				symlinkFile.make_symbolic_link(extension.settings.get_string("fonts-path") + "/" + fontGroup._fontGroupName, null);
			} catch (err) {
			}
		}
	},

	_removeMenu: function() {
		if (!this.menu.isEmpty()) {
			this.menu.removeAll();
		}
	},
	
	destroy: function() {
		this.parent();
		
		this._icon = null;
		
		for (let id in this._fontGroup) {
			this._fontGroup[id].disconnect(this._fontGroupConnectId[id]);
			this._fontGroup[id].destroy();
			this._fontGroupConnectId = null;
		}
	
		this._fontGroup = null;
	}
});



const SimpleFontManagerExtension = new Lang.Class({
	Name: "SimpleFontManagerExtension",

	_init: function() {
		Convenience.initTranslations();
		
		this.settings = Convenience.getSettings();

		if (this.settings.get_string("fonts-path") == "~/Fonts") {
			this.settings.set_string('fonts-path', "/home/" + GLib.get_user_name() + "/Fonts");
		}

		this._indicator = null;
	},
	
	_createIndicator: function() {
		this._indicator = new SimpleFontManagerIndicator();

		Main.panel.addToStatusArea("simple-font-manager-indicator", this._indicator);
	},

	launchSettings: function() {
		try {
			Util.spawn(["gnome-shell-extension-prefs", "simple-font-manager@zardoz"]);
		} catch (err) {
		}
	},

	enable: function() {
		this._createIndicator();
		
		this._setting_changed = this.settings.connect("changed::fonts-path", Lang.bind(this, this._indicator.updateMenu));
	},
	
	disable: function() {
		this._indicator.destroy();
		this._indicator = null;
		
		this.settings.disconnect(this._setting_changed);
		this._setting_changed = null;
	}
});
	
let extension;

function init(extensionMeta) {
	let theme = imports.gi.Gtk.IconTheme.get_default();
	theme.append_search_path(extensionMeta.path + "/icons");
	
	return (extension = new SimpleFontManagerExtension());
}
