const GObject = imports.gi.GObject;
const GLib = imports.gi.GLib;
const Gtk = imports.gi.Gtk;

const Gettext = imports.gettext.domain("gnome-shell-extensions-simple-font-manager");
const _ = Gettext.gettext;

const Extension = imports.misc.extensionUtils.getCurrentExtension();
const Convenience = Extension.imports.convenience;

let settings;

function prepareFontPath() {
	if (settings.get_string("fonts-path") == "~/Fonts") {
		settings.set_string('fonts-path', "/home/" + GLib.get_user_name() + "/Fonts");
	}
}

function createSettingsWidget() {
	let vbox = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL });
	
	let hbox_fontsPath = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL });
	
	let fontsPathLabel = new Gtk.Label({ label: _("Fonts folder:"), use_markup: true, xalign: 0 });
	
	let fontsPathFileChooserButton = new Gtk.FileChooserButton({
		title: _("Select fonts folder:"),
		action: Gtk.FileChooserAction.SELECT_FOLDER
	});

	fontsPathFileChooserButton.set_current_folder(settings.get_string("fonts-path"));
	
	fontsPathFileChooserButton.connect('file-set', function() {
		settings.set_string('fonts-path', fontsPathFileChooserButton.get_filename());
	});
	
	hbox_fontsPath.pack_start(fontsPathLabel, true, true, 0);
	hbox_fontsPath.add(fontsPathFileChooserButton);

	vbox.add(hbox_fontsPath);
	
	return vbox;
}

function buildPrefsWidget() {
  let frame = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL, border_width: 10 });
  let vbox = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL, margin: 20 });
  let settingsWidget = createSettingsWidget();
  
  vbox.add(settingsWidget);
  
  frame.add(vbox);
  frame.show_all();
  
  return frame;
}

function init() {
	Convenience.initTranslations();
	
	settings = Convenience.getSettings();
	
	prepareFontPath();
}
